==> thux.price-1.0.0.tar.gz: thux.price-1.0.0/setup.py <==
# http://www.28lines.com/?p=8
import os
import re
from setuptools import setup, find_packages
from setuptools.command.test import test


class TestRunner(test):
    def run(self, *args, **kwargs):
        if self.distribution.install_requires:
            self.distribution.fetch_build_eggs(
                self.distribution.install_requires)
        if self.distribution.tests_require:
            self.distribution.fetch_build_eggs(
                self.distribution.tests_require)
        from thux.price.tests.runtests import runtests
        runtests()


def get_data_files(*args, **kwargs):
    EXT_PATTERN = kwargs.get('ext') or '\.(html|js|txt|css|po|mo|png|json|xml|yml)'

    data_dict = {}
    for pkg_name in args:
        data_files = []
        for dirpath, dirnames, filenames in os.walk(pkg_name.replace('.', '/')):
            rel_dirpath = re.sub("^" + pkg_name + '/', '', dirpath)
            # Ignore dirnames that start with '.'
            for i, dirname in enumerate(dirnames):
                if dirname.startswith('.'): del dirnames[i]
            if filenames:
                data_files += [os.path.join(rel_dirpath, f) for f in filenames
                               if re.search(EXT_PATTERN, f)]
        data_dict[pkg_name] = data_files
    return data_dict


setup(
    name='thux.price',
    namespace_packages=['thux'],
    version="1.0.0",
    description='Price Application',
    author='THUX',
    url='http://hg.thundersystems.it/thux/thux.price',
    author_email='dev@thundersystems.it',
    packages=find_packages(exclude=['tests', 'tests.*']),
    platforms='any',
    zip_safe=False,
    classifiers=[
        'Environment :: Jumbo',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Framework :: Django',
        'Framework :: Jumbo',
    ],
    test_suite="thux.price.tests",
    cmdclass={"test": TestRunner},
    install_requires=[
        'setuptools',
        'jmb.core>=0.4',
        'thux.address',
        'thux.carriage',
        'thux.currency',
        'thux.i18n',
        'thux.l10n',
        'thux.office',
        'thux.organization',
        'thux.payment',
        'thux.price',
        'thux.product',
        'thux.store',
        'thux.vat',
    ],
    package_data=get_data_files('thux.price')
)

==> thux.price-2.0.1.tar.gz: thux.price-2.0.1/setup.py <==
# http://www.28lines.com/?p=8
import os
import re
from setuptools import setup, find_packages
from setuptools.command.test import test


class TestRunner(test):
    def run(self, *args, **kwargs):
        if self.distribution.install_requires:
            self.distribution.fetch_build_eggs(
                self.distribution.install_requires)
        if self.distribution.tests_require:
            self.distribution.fetch_build_eggs(
                self.distribution.tests_require)
        from thux.price.tests.runtests import runtests
        runtests()


def get_data_files(*args, **kwargs):
    EXT_PATTERN = kwargs.get('ext') or '\.(html|js|txt|css|po|mo|png|json|xml|yml)'

    data_dict = {}
    for pkg_name in args:
        data_files = []
        for dirpath, dirnames, filenames in os.walk(pkg_name.replace('.', '/')):
            rel_dirpath = re.sub("^" + pkg_name + '/', '', dirpath)
            # Ignore dirnames that start with '.'
            for i, dirname in enumerate(dirnames):
                if dirname.startswith('.'): del dirnames[i]
            if filenames:
                data_files += [os.path.join(rel_dirpath, f) for f in filenames
                               if re.search(EXT_PATTERN, f)]
        data_dict[pkg_name] = data_files
    return data_dict


setup(
    name='thux.price',
    namespace_packages=['thux'],
    version="2.0.1",
    description='Price Application',
    author='THUX',
    url='http://hg.thundersystems.it/thux/thux.price',
    author_email='dev@thundersystems.it',
    packages=find_packages(exclude=['tests', 'tests.*']),
    platforms='any',
    zip_safe=False,
    classifiers=[
        'Environment :: Jumbo',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Framework :: Django',
        'Framework :: Jumbo',
    ],
    test_suite="thux.price.tests",
    cmdclass={"test": TestRunner},
    install_requires=[
        'setuptools',
        'djangorestframework',
        'thux.api',
        'thux.product>=2.0.0',
        'thux.organization>=2.0.1',
        'thux.currency>=2.0.1',
        'thux.vat>=2.0.1',
    ],
    package_data=get_data_files('thux.price')
)
